ResolveErrorKind

Enum ResolveErrorKind 

#[non_exhaustive]
pub enum ResolveErrorKind { PackageNotFound { span: Span, requested: PackageName, known: Vec<PackageName>, }, InvalidTransitiveDependency { span: Span, name: String, }, DuplicatePackage { name: PackageName, span1: Span, span2: Span, }, PackageCycle { package: PackageName, span: Span, }, ItemShadowing { span: Span, item_type: String, name: String, }, StabilityMismatch { span: Span, from: Stability, into: Stability, }, Semantic { span: Span, message: String, }, }
The category of error that occurred while resolving a WIT package.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PackageNotFound

A referenced package could not be found among the known packages.

Fields

span: Span
requested: PackageName


InvalidTransitiveDependency

An interface has a transitive dependency that creates an incompatible import relationship.

Fields

span: Span
name: String


DuplicatePackage

The same package is defined in two different locations.

Fields

span1: Span
span2: Span


PackageCycle

Packages form a dependency cycle.

Fields

package: PackageName
span: Span


ItemShadowing

A world item shadows a previously-included item of the same kind

Fields

span: Span
item_type: String
name: String


StabilityMismatch

Two stability annotations conflict during merge

Fields

span: Span


Semantic

A semantic error during resolution (type mismatch, invalid use, etc.)

Fields

span: Span
message: String

Implementations

Source

impl ResolveErrorKind

pub fn span(&self) -> Span

Returns the source span associated with this error.