Skip to main content Crate wit_parser Copy item path Source abi decoding error Error types for WIT package resolution. ArchitectureSize Architecture specific measurement of position,
the combined amount in bytes is
bytes + pointers * core::mem::size_of::<*const u8>() Case CloneMaps Represents the results of cloning types and/or interfaces as part of a
Resolve::merge_worlds operation. Docs ElementInfo Information per structure element Enum EnumCase Field Flag Flags Function IncludeName Interface ItemName The fully-qualified name of a Component Model item (function,
type, or resource) as can be defined by wit. An item is optionally in a
package, the package optionally has a version, and the item is optionally
inside a namespace. LiveTypes Package A WIT package within a Resolve. PackageMetadata Represents serializable doc comments parsed from a WIT package. PackageName A structure used to keep track of the name of a package, containing optional
information such as a namespace and version information. PackageSourceMap All the sources used during resolving a directory or path. PackageSources Source name mappings for resolved packages (no_std compatible). Param ParseError A single structured error from parsing a WIT package. Record Remap Structure returned by Resolve::merge which contains mappings from
old-ids to new-ids after the merge. Resolve Representation of a fully resolved set of WIT packages. ResolveError A single structured error from resolving a WIT package. Result_ SizeAlign Collect size and alignment for sub-elements of a structure SourceMap A listing of source files which are used to get parsed into an
UnresolvedPackage . Span A span, designating a range of bytes where a token is located. Tuple TypeDef UnresolvedPackage Representation of a parsed WIT package which has not resolved external
dependencies yet. UnresolvedPackageGroup Tracks a set of packages, all pulled from the same group of WIT source files. Variant World WorldInclude An entry in the includes list of a world, representing an include
statement in WIT. Alignment Architecture specific alignment AstItem FlagsRepr FunctionKind FutureIntrinsic Intrinsic definitions to go with WasmImport::FutureIntrinsic which
also goes with Resolve::wasm_import_name . Handle Int LiftLowerAbi Possible lift/lower ABI choices supported when mangling names. Mangling Possible forms of name mangling that are supported by this crate. ManglingAndAbi Combination of Mangling and LiftLowerAbi . ParseErrorKind The category of error that occurred while parsing a WIT package. ParsedUsePath ResolveErrorKind The category of error that occurred while resolving a WIT package. ResourceIntrinsic Intrinsic definitions to go with WasmImport::ResourceIntrinsic which
also goes with Resolve::wasm_import_name . Stability Representation of the stability attributes associated with a world,
interface, function, or type. StreamIntrinsic Intrinsic definitions to go with WasmImport::StreamIntrinsic which
also goes with Resolve::wasm_import_name . Type TypeDefKind TypeOwner WasmExport Different kinds of exports that can be passed to
Resolve::wasm_export_name to export from core wasm modules. WasmExportKind Indicates whether a function export is a normal export, a post-return
function, or a callback function. WasmImport Possible imports that can be passed to Resolve::wasm_import_name . WorldItem WorldKey The key to the import/export maps of a world. Either a kebab-name or a
unique interface. TypeIdVisitor Helper trait to walk the structure of a type and visit all TypeIds that
it refers to, possibly transitively. align_to_arch Increase val to a multiple of align, with special handling for pointers;
align must be a power of two or Alignment::Pointer parse_use_path render_anyhow_error Renders an anyhow::Error chain produced by this crate, substituting
snippet-bearing output for any ResolveError or ParseError layers. validate_id Checks if the given string is a legal identifier in wit. IndexMap IndexSet InterfaceId PackageId ParseResult Convenience alias for a Result whose error type is ParseError . ResolveResult Convenience alias for a Result whose error type is ResolveError . TypeId WorldId