ParseErrorKind

Enum ParseErrorKind 

#[non_exhaustive]
pub enum ParseErrorKind { Lex(Error), Syntax { span: Span, message: String, }, ItemNotFound { span: Span, name: String, kind: String, hint: Option<String>, }, TypeCycle { span: Span, name: String, kind: String, }, }
The category of error that occurred while parsing a WIT package.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Lex(Error)

Lexer error (invalid character, unterminated comment, etc.)



Syntax

Syntactic or semantic error within a single package (duplicate name, invalid attribute, etc.)

Fields

span: Span
message: String


ItemNotFound

A type/interface/world references a name that does not exist within the same package.

Fields

span: Span
name: String
kind: String


TypeCycle

A type/interface/world depends on itself.

Fields

span: Span
name: String
kind: String

Implementations

Source

impl ParseErrorKind

pub fn span(&self) -> Span

Returns the source span associated with this error.