#[non_exhaustive]pub enum ResolveErrorKind {
PackageNotFound {
span: Span,
requested: PackageName,
known: Vec<PackageName>,
},
InvalidTransitiveDependency {
span: Span,
name: String,
},
DuplicatePackage {
name: PackageName,
span1: Span,
span2: Span,
},
PackageCycle {
package: PackageName,
span: Span,
},
ItemShadowing {
span: Span,
item_type: String,
name: String,
},
StabilityMismatch {
span: Span,
from: Stability,
into: Stability,
},
Semantic {
span: Span,
message: String,
},
}Expand description
The category of error that occurred while resolving a WIT package.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PackageNotFound
A referenced package could not be found among the known packages.
InvalidTransitiveDependency
An interface has a transitive dependency that creates an incompatible import relationship.
DuplicatePackage
The same package is defined in two different locations.
PackageCycle
Packages form a dependency cycle.
ItemShadowing
A world item shadows a previously-included item of the same kind
StabilityMismatch
Two stability annotations conflict during merge
Semantic
A semantic error during resolution (type mismatch, invalid use, etc.)
Implementations