pub struct UnresolvedPackageGroup {
pub main: UnresolvedPackage,
pub nested: Vec<UnresolvedPackage>,
pub source_map: SourceMap,
}Expand description
Tracks a set of packages, all pulled from the same group of WIT source files.
Fields
main: UnresolvedPackageThe “main” package in this package group which was found at the root of the WIT files.
Note that this is required to be present in all WIT files.
nested: Vec<UnresolvedPackage>Nested packages found while parsing main, if any.
source_map: SourceMapA set of processed source files from which these packages have been parsed.
Implementations
Sourceimpl UnresolvedPackageGroup
impl UnresolvedPackageGroup
Sourcepub fn parse(
path: impl AsRef<Path>,
contents: &str,
) -> Result<UnresolvedPackageGroup>
pub fn parse( path: impl AsRef<Path>, contents: &str, ) -> Result<UnresolvedPackageGroup>
Parses the given string as a wit document.
The path argument is used for error reporting. The contents provided
are considered to be the contents of path. This function does not read
the filesystem.
Sourcepub fn parse_dir(path: impl AsRef<Path>) -> Result<UnresolvedPackageGroup>
pub fn parse_dir(path: impl AsRef<Path>) -> Result<UnresolvedPackageGroup>
Parses a WIT package from the directory provided.
This method will look at all files under the path specified. All
*.wit files are parsed and assumed to be part of the same package
grouping. This is useful when a WIT package is split across multiple
files.